@@ -12,6 +12,9 @@ import math
 import gobject
 import pygst
 import email
+from subprocess import PIPE, Popen
+from threading import Thread
+from Queue import Queue, Empty
 
 pygst.require('0.10')
 gobject.threads_init()
@@ -25,10 +28,17 @@ try:
 	from portrait import FremantleRotation
 	app_name = "Saera"
 	app_version = "1.0"
-	initial_mode = FremantleRotation.ALWAYS
+	initial_mode = FremantleRotation.AUTOMATIC
 except ImportError:
 	pass
 
+ON_POSIX = 'posix' in sys.builtin_module_names
+
+def enqueue_output(out, queue):
+    for line in iter(out.readline, ''):
+        queue.put(line)
+    out.close()
+
 pulsing = False
 rot_amount = 0
 WIDTH = 0
@@ -117,6 +127,12 @@ class Saera:
 
 		self.current_message = None
 
+		self.mod = Popen(['python', '/opt/modrana/modrana.py', '--return-current-coordinates'], stdout=PIPE, bufsize=1, close_fds=ON_POSIX)
+		self.q = Queue()
+		self.t = Thread(target=enqueue_output, args=(self.mod.stdout, q.self))
+		self.t.daemon = True # thread dies with the program
+		self.t.start()
+
 	def expose_event(self, widget, event):
 		global WIDTH, HEIGHT
 		cr = widget.window.cairo_create()
@@ -397,6 +413,13 @@ class Saera:
     
 
 	def run_saera(self, widget=None, event=None, data=None):
+		try:
+			coords = self.q.get_nowait()
+		except Empty:
+			pass
+		else:
+			saera_processing.location = coords
+			print "Coords: ", coords
 		if event=="speech-event":
 			text = data[0].upper()+data[1:].lower().replace(" and nine hundred", " N900")
 		else:
